@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.4
+# Application Name - Health Check V0.5.0-1
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -291,8 +291,6 @@ class Ui_MainWindow(object):
         # Draw the Tab Contents
         self.tabWidget.addTab(self.tab, "")
         
-        
-        
         # Start on tab 5!
         self.tab_2 = QtGui.QWidget()
         self.tab_2.setObjectName("tab_2")
@@ -302,14 +300,11 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_2)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.4.2-9 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com")
+        self.textBrowser.setText (" Health Check V 0.5.0-1 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
         self.textBrowser.setFont(font)
-        
-        # Read the local variable var_l_applist, this was called at the beginning, pulling the app list in
-        
 
         # Show the tab and draw contents
         self.tabWidget.addTab(self.tab_2, "")
@@ -323,13 +318,11 @@ class Ui_MainWindow(object):
         MainWindow.setMenuBar(self.menubar)
         # Draw the Status bar
         #self.statusbar = QtGui.QStatusBar(MainWindow)
-        #self.statusbar.setObjectName("statusbar")
-        #MainWindow.setStatusBar(self.statusbar)
-        
+
         # Run the translate UI - Added by QT Designer - i have removed alot of setText's and placed them above.
         self.retranslateUi(MainWindow)
-        self.updateTab1()
-        
+        #self.updateTab1()
+        Thread(target=self.updateTab1()).start()
 
         # Set which tab you want showing on program load
         self.tabWidget.setCurrentIndex(0)
@@ -341,8 +334,9 @@ class Ui_MainWindow(object):
         global var_g_GPS
         # Start of the GPS Location information
         # Please visit here for more information and code on PyMaemo GPS API - http://wiki.maemo.org/PyMaemo/Using_Location_API
-        control = location.GPSDControl.get_default()
-        device = location.GPSDevice()
+
+        #control = location.GPSDControl.get_default()
+        #device = location.GPSDevice()
         
         loop = gobject.MainLoop()
         control = location.GPSDControl.get_default()
